/*
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This code is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this code; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.  */

/* Copyright (C) 2001 Ian Zimmerman <itz@speakeasy.org> */

#ifndef INCLUDE_CLIENTCON_H
#define INCLUDE_CLIENTCON_H

/* $Id: clientcon.h,v 1.11 2002/08/26 07:16:52 itz Exp $ */

extern const char* gim_server_err_message;

/* START PUBLIC */

#include <sys/types.h>

void
gim_init (void);

struct gim_client_masks {
  unsigned minmod;
  unsigned maxmod;
  unsigned handle;
  unsigned pass;
};

int
gim_client_connect (const struct gim_client_masks* p_masks, int vt, const char* device);

#define GIM_CONNECT_CMD_FAILURE GIM_CMD_FAILURE
#define GIM_CONNECT_ERR_GREETING -2
#define GIM_CONNECT_ERR_VERSION -3
#define GIM_CONNECT_NO_CTTY -4
#define GIM_CONNECT_ERR_UNIX GIM_ERR_UNIX
#define GIM_CONNECT_ERR_UNKNOWN GIM_ERR_UNKNOWN

                                /* returns 0 on success */
int
gim_client_close (int fd);

#define GIM_CLOSE_SUCCESS GIM_SUCCESS
#define GIM_CLOSE_CMD_FAILURE GIM_CMD_FAILURE
#define GIM_CLOSE_ERR_UNKNOWN GIM_ERR_UNKNOWN

int
gim_client_set_masks (int fd, const struct gim_client_masks* p_masks);

#define GIM_SET_MASKS_SUCCESS GIM_SUCCESS
#define GIM_SET_MASKS_CMD_FAILURE GIM_CMD_FAILURE
#define GIM_SET_MASKS_ERR_UNKNOWN GIM_ERR_UNKNOWN

int
gim_client_get_masks (int fd, struct gim_client_masks* p_masks);

#define GIM_GET_MASKS_SUCCESS GIM_SUCCESS
#define GIM_GET_MASKS_CMD_FAILURE GIM_CMD_FAILURE
#define GIM_GET_MASKS_ERR_UNKNOWN GIM_ERR_UNKNOWN

int
gim_client_draw_pointer (int fd, int x, int y);

#define GIM_DRAW_POINTER_SUCCESS GIM_SUCCESS
#define GIM_DRAW_POINTER_CMD_FAILURE GIM_CMD_FAILURE
#define GIM_DRAW_POINTER_ERR_UNKNOWN GIM_ERR_UNKNOWN

int
gim_client_stop (int fd);

#define GIM_STOP_SUCCESS GIM_SUCCESS
#define GIM_STOP_CMD_FAILURE GIM_CMD_FAILURE
#define GIM_STOP_ERR_UNKNOWN GIM_ERR_UNKNOWN

extern int
gim_client_start (int fd);

#define GIM_START_SUCCESS GIM_SUCCESS
#define GIM_START_CMD_FAILURE GIM_CMD_FAILURE
#define GIM_START_ERR_UNKNOWN GIM_ERR_UNKNOWN

/* returns length of copied string (even if it is not actually copied
   because it's too long for the supplied buffer */

int
gim_client_devinfo (int fd, char* info, size_t info_size);

#define GIM_DEVINFO_CMD_FAILURE GIM_CMD_FAILURE
#define GIM_DEVINFO_ERR_UNKNOWN GIM_ERR_UNKNOWN

int
gim_client_servinfo (int fd, char* info, size_t info_size);

#define GIM_SERVINFO_CMD_FAILURE GIM_CMD_FAILURE
#define GIM_SERVINFO_ERR_UNKNOWN GIM_ERR_UNKNOWN

int
gim_client_disable_paste (int fd);

#define GIM_DISABLE_PASTE_SUCCESS GIM_SUCCESS
#define GIM_DISABLE_PASTE_CMD_FAILURE GIM_CMD_FAILURE
#define GIM_DISABLE_PASTE_ERR_UNKNOWN GIM_ERR_UNKNOWN

/* END PUBLIC */

#endif /* INCLUDE_CLIENTCON_H */
